==> quasar-1.1.0.jar: META-INF/resources/webjars/quasar/1.1.0/icon-set/material-icons-sharp.js <==
export default {
  name: 'material-icons-sharp',
  type: {
    positive: 's_check_circle',
    negative: 's_warning',
    info: 's_info',
    warning: 's_priority_high'
  },
  arrow: {
    up: 's_arrow_upward',
    right: 's_arrow_forward',
    down: 's_arrow_downward',
    left: 's_arrow_back',
    dropdown: 's_arrow_drop_down'
  },
  chevron: {
    left: 's_chevron_left',
    right: 's_chevron_right'
  },
  colorPicker: {
    spectrum: 's_gradient',
    tune: 's_tune',
    palette: 's_style'
  },
  pullToRefresh: {
    icon: 's_refresh'
  },
  carousel: {
    left: 's_chevron_left',
    right: 's_chevron_right',
    navigationIcon: 's_lens',
    thumbnails: 's_view_carousel'
  },
  chip: {
    remove: 's_cancel',
    selected: 's_check'
  },
  datetime: {
    arrowLeft: 's_chevron_left',
    arrowRight: 's_chevron_right',
    now: 's_access_time',
    today: 's_today'
  },
  editor: {
    bold: 's_format_bold',
    italic: 's_format_italic',
    strikethrough: 's_strikethrough_s',
    underline: 's_format_underlined',
    unorderedList: 's_format_list_bulleted',
    orderedList: 's_format_list_numbered',
    subscript: 's_vertical_align_bottom',
    superscript: 's_vertical_align_top',
    hyperlink: 's_link',
    toggleFullscreen: 's_fullscreen',
    quote: 's_format_quote',
    left: 's_format_align_left',
    center: 's_format_align_center',
    right: 's_format_align_right',
    justify: 's_format_align_justify',
    print: 's_print',
    outdent: 's_format_indent_decrease',
    indent: 's_format_indent_increase',
    removeFormat: 's_format_clear',
    formatting: 's_text_format',
    fontSize: 's_format_size',
    align: 's_format_align_left',
    hr: 's_remove',
    undo: 's_undo',
    redo: 's_redo',
    header: 's_format_size',
    code: 's_code',
    size: 's_format_size',
    font: 's_font_download'
  },
  expansionItem: {
    icon: 's_keyboard_arrow_down',
    denseIcon: 's_arrow_drop_down'
  },
  fab: {
    icon: 's_add',
    activeIcon: 's_close'
  },
  field: {
    clear: 's_cancel',
    error: 's_error'
  },
  pagination: {
    first: 's_first_page',
    prev: 's_keyboard_arrow_left',
    next: 's_keyboard_arrow_right',
    last: 's_last_page'
  },
  rating: {
    icon: 's_grade'
  },
  stepper: {
    done: 's_check',
    active: 's_edit',
    error: 's_warning'
  },
  tabs: {
    left: 's_chevron_left',
    right: 's_chevron_right',
    up: 's_keyboard_arrow_up',
    down: 's_keyboard_arrow_down'
  },
  table: {
    arrowUp: 's_arrow_upward',
    warning: 's_warning',
    prevPage: 's_chevron_left',
    nextPage: 's_chevron_right'
  },
  tree: {
    icon: 's_play_arrow'
  },
  uploader: {
    done: 's_done',
    clear: 's_clear',
    add: 's_add_box',
    upload: 's_cloud_upload',
    removeQueue: 's_clear_all',
    removeUploaded: 's_done_all'
  }
}

==> quasar-1.4.2.jar: META-INF/resources/webjars/quasar/1.4.2/icon-set/material-icons-sharp.js <==
export default {
  name: 'material-icons-sharp',
  type: {
    positive: 's_check_circle',
    negative: 's_warning',
    info: 's_info',
    warning: 's_priority_high'
  },
  arrow: {
    up: 's_arrow_upward',
    right: 's_arrow_forward',
    down: 's_arrow_downward',
    left: 's_arrow_back',
    dropdown: 's_arrow_drop_down'
  },
  chevron: {
    left: 's_chevron_left',
    right: 's_chevron_right'
  },
  colorPicker: {
    spectrum: 's_gradient',
    tune: 's_tune',
    palette: 's_style'
  },
  pullToRefresh: {
    icon: 's_refresh'
  },
  carousel: {
    left: 's_chevron_left',
    right: 's_chevron_right',
    navigationIcon: 's_lens',
    thumbnails: 's_view_carousel'
  },
  chip: {
    remove: 's_cancel',
    selected: 's_check'
  },
  datetime: {
    arrowLeft: 's_chevron_left',
    arrowRight: 's_chevron_right',
    now: 's_access_time',
    today: 's_today'
  },
  editor: {
    bold: 's_format_bold',
    italic: 's_format_italic',
    strikethrough: 's_strikethrough_s',
    underline: 's_format_underlined',
    unorderedList: 's_format_list_bulleted',
    orderedList: 's_format_list_numbered',
    subscript: 's_vertical_align_bottom',
    superscript: 's_vertical_align_top',
    hyperlink: 's_link',
    toggleFullscreen: 's_fullscreen',
    quote: 's_format_quote',
    left: 's_format_align_left',
    center: 's_format_align_center',
    right: 's_format_align_right',
    justify: 's_format_align_justify',
    print: 's_print',
    outdent: 's_format_indent_decrease',
    indent: 's_format_indent_increase',
    removeFormat: 's_format_clear',
    formatting: 's_text_format',
    fontSize: 's_format_size',
    align: 's_format_align_left',
    hr: 's_remove',
    undo: 's_undo',
    redo: 's_redo',
    header: 's_format_size',
    code: 's_code',
    size: 's_format_size',
    font: 's_font_download',
    viewSource: 's_code'
  },
  expansionItem: {
    icon: 's_keyboard_arrow_down',
    denseIcon: 's_arrow_drop_down'
  },
  fab: {
    icon: 's_add',
    activeIcon: 's_close'
  },
  field: {
    clear: 's_cancel',
    error: 's_error'
  },
  pagination: {
    first: 's_first_page',
    prev: 's_keyboard_arrow_left',
    next: 's_keyboard_arrow_right',
    last: 's_last_page'
  },
  rating: {
    icon: 's_grade'
  },
  stepper: {
    done: 's_check',
    active: 's_edit',
    error: 's_warning'
  },
  tabs: {
    left: 's_chevron_left',
    right: 's_chevron_right',
    up: 's_keyboard_arrow_up',
    down: 's_keyboard_arrow_down'
  },
  table: {
    arrowUp: 's_arrow_upward',
    warning: 's_warning',
    prevPage: 's_chevron_left',
    nextPage: 's_chevron_right'
  },
  tree: {
    icon: 's_play_arrow'
  },
  uploader: {
    done: 's_done',
    clear: 's_clear',
    add: 's_add_box',
    upload: 's_cloud_upload',
    removeQueue: 's_clear_all',
    removeUploaded: 's_done_all'
  }
}
